searchData={"items":[{"type":"module","title":"MemorableIds","doc":"Memorable ID Generator\n\nA flexible library for generating human-readable, memorable identifiers.\nUses combinations of adjectives, nouns, verbs, adverbs, and prepositions\nwith optional numeric/custom suffixes.","ref":"MemorableIds.html"},{"type":"function","title":"MemorableIds.calculate_collision_probability/2","doc":"Calculate collision probability using Birthday Paradox","ref":"MemorableIds.html#calculate_collision_probability/2"},{"type":"function","title":"Examples - MemorableIds.calculate_collision_probability/2","doc":"iex> total_combinations = MemorableIds.calculate_combinations(2)\n    iex> prob = MemorableIds.calculate_collision_probability(total_combinations, 100)\n    iex> is_float(prob) and prob >= 0.0 and prob <= 1.0\n    true\n\n    iex> total_combinations = MemorableIds.calculate_combinations(3)\n    iex> prob = MemorableIds.calculate_collision_probability(total_combinations, 10000)\n    iex> is_float(prob) and prob >= 0.0 and prob <= 1.0\n    true","ref":"MemorableIds.html#calculate_collision_probability/2-examples"},{"type":"function","title":"MemorableIds.calculate_combinations/2","doc":"Calculate total possible combinations for given configuration","ref":"MemorableIds.html#calculate_combinations/2"},{"type":"function","title":"Examples - MemorableIds.calculate_combinations/2","doc":"iex> combinations = MemorableIds.calculate_combinations(2)\n    iex> stats = MemorableIds.Dictionary.stats()\n    iex> combinations == stats.adjectives * stats.nouns\n    true\n\n    iex> combinations = MemorableIds.calculate_combinations(2, 1000)\n    iex> stats = MemorableIds.Dictionary.stats()\n    iex> combinations == stats.adjectives * stats.nouns * 1000\n    true\n\n    iex> combinations = MemorableIds.calculate_combinations(3)\n    iex> stats = MemorableIds.Dictionary.stats()\n    iex> combinations == stats.adjectives * stats.nouns * stats.verbs\n    true","ref":"MemorableIds.html#calculate_combinations/2-examples"},{"type":"function","title":"MemorableIds.default_suffix/0","doc":"Default suffix generator - random 3-digit number","ref":"MemorableIds.html#default_suffix/0"},{"type":"function","title":"Examples - MemorableIds.default_suffix/0","doc":"iex> suffix = MemorableIds.default_suffix()\n    iex> String.match?(suffix, ~r/^\\d{3}$/)\n    true\n\n    iex> suffix = MemorableIds.default_suffix()\n    iex> String.length(suffix)\n    3","ref":"MemorableIds.html#default_suffix/0-examples"},{"type":"function","title":"MemorableIds.generate/1","doc":"Generate a memorable ID","ref":"MemorableIds.html#generate/1"},{"type":"function","title":"Options - MemorableIds.generate/1","doc":"* `:components` - Number of word components (1-5, default: 2)\n* `:suffix` - Suffix generator function (default: nil)\n* `:separator` - Separator between parts (default: \"-\")","ref":"MemorableIds.html#generate/1-options"},{"type":"function","title":"Examples - MemorableIds.generate/1","doc":"iex> id = MemorableIds.generate()\n    iex> String.contains?(id, \"-\")\n    true\n\n    iex> id = MemorableIds.generate(%{components: 3})\n    iex> length(String.split(id, \"-\"))\n    3\n\n    iex> id = MemorableIds.generate(%{components: 2, suffix: &MemorableIds.default_suffix/0})\n    iex> String.match?(id, ~r/.*-\\d{3}$/)\n    true\n\n    iex> id = MemorableIds.generate(%{components: 2, separator: \"_\"})\n    iex> String.contains?(id, \"_\")\n    true","ref":"MemorableIds.html#generate/1-examples"},{"type":"function","title":"MemorableIds.get_collision_analysis/2","doc":"Get collision analysis for different ID generation scenarios","ref":"MemorableIds.html#get_collision_analysis/2"},{"type":"function","title":"Examples - MemorableIds.get_collision_analysis/2","doc":"iex> analysis = MemorableIds.get_collision_analysis(2)\n    iex> expected = MemorableIds.calculate_combinations(2)\n    iex> analysis.total_combinations == expected\n    true\n\n    iex> analysis = MemorableIds.get_collision_analysis(2)\n    iex> is_list(analysis.scenarios)\n    true\n\n    iex> analysis = MemorableIds.get_collision_analysis(2)\n    iex> length(analysis.scenarios) >= 0\n    true","ref":"MemorableIds.html#get_collision_analysis/2-examples"},{"type":"function","title":"MemorableIds.parse/2","doc":"Parse a memorable ID back to its components","ref":"MemorableIds.html#parse/2"},{"type":"function","title":"Examples - MemorableIds.parse/2","doc":"iex> MemorableIds.parse(\"cute-rabbit-042\")\n    %{components: [\"cute\", \"rabbit\"], suffix: \"042\"}\n\n    iex> MemorableIds.parse(\"large-fox-swim\")\n    %{components: [\"large\", \"fox\", \"swim\"], suffix: nil}\n\n    iex> MemorableIds.parse(\"cute_rabbit_123\", \"_\")\n    %{components: [\"cute\", \"rabbit\"], suffix: \"123\"}","ref":"MemorableIds.html#parse/2-examples"},{"type":"function","title":"MemorableIds.suffix_generators/0","doc":"Collection of predefined suffix generators","ref":"MemorableIds.html#suffix_generators/0"},{"type":"function","title":"Examples - MemorableIds.suffix_generators/0","doc":"iex> generators = MemorableIds.suffix_generators()\n    iex> is_map(generators)\n    true\n\n    iex> generators = MemorableIds.suffix_generators()\n    iex> is_function(generators.number, 0)\n    true","ref":"MemorableIds.html#suffix_generators/0-examples"},{"type":"module","title":"MemorableIds.Dictionary","doc":"Dictionary of words for memorable ID generation\n\nContains collections of English words categorized by part of speech.\nUsed to generate human-readable, memorable identifiers.","ref":"MemorableIds.Dictionary.html"},{"type":"function","title":"MemorableIds.Dictionary.adjectives/0","doc":"English adjectives (78 total)\nDescriptive words that modify nouns","ref":"MemorableIds.Dictionary.html#adjectives/0"},{"type":"function","title":"MemorableIds.Dictionary.adverbs/0","doc":"English adverbs (27 total)\nWords that modify verbs, adjectives, or other adverbs","ref":"MemorableIds.Dictionary.html#adverbs/0"},{"type":"function","title":"MemorableIds.Dictionary.all/0","doc":"Get all word collections grouped by type","ref":"MemorableIds.Dictionary.html#all/0"},{"type":"function","title":"Examples - MemorableIds.Dictionary.all/0","doc":"iex> dictionary = MemorableIds.Dictionary.all()\n    iex> is_list(dictionary.adjectives)\n    true\n    iex> is_map(dictionary.stats)\n    true","ref":"MemorableIds.Dictionary.html#all/0-examples"},{"type":"function","title":"MemorableIds.Dictionary.nouns/0","doc":"English nouns - animals and common objects (68 total)\nConcrete things, animals, and objects","ref":"MemorableIds.Dictionary.html#nouns/0"},{"type":"function","title":"MemorableIds.Dictionary.prepositions/0","doc":"English prepositions (26 total)\nWords that show relationships between other words","ref":"MemorableIds.Dictionary.html#prepositions/0"},{"type":"function","title":"MemorableIds.Dictionary.random_word/1","doc":"Get a random word from specified category","ref":"MemorableIds.Dictionary.html#random_word/1"},{"type":"function","title":"Examples - MemorableIds.Dictionary.random_word/1","doc":"iex> word = MemorableIds.Dictionary.random_word(:adjectives)\n    iex> word in MemorableIds.Dictionary.adjectives()\n    true","ref":"MemorableIds.Dictionary.html#random_word/1-examples"},{"type":"function","title":"MemorableIds.Dictionary.stats/0","doc":"Dictionary statistics for combination calculations","ref":"MemorableIds.Dictionary.html#stats/0"},{"type":"function","title":"MemorableIds.Dictionary.verbs/0","doc":"English verbs - present tense (40 total)\nAction words in present tense form","ref":"MemorableIds.Dictionary.html#verbs/0"},{"type":"extras","title":"MemorableIds","doc":"# MemorableIds\n\nA flexible Elixir library for generating human-readable, memorable identifiers.\nUses combinations of adjectives, nouns, verbs, adverbs, and prepositions with optional numeric/custom suffixes.\n\nTypeScript version of this library: [memorable-ids](https://www.npmjs.com/package/memorable-ids)","ref":"readme.html"},{"type":"extras","title":"Features - MemorableIds","doc":"- 🎯 **Human-readable** - Generate IDs like `cute-rabbit`, `quick-owl-dance-quietly`, etc\n- 🔧 **Flexible** - 1-5 word components with customizable separators\n- 📊 **Predictable** - Built-in collision analysis and capacity planning\n- 🎲 **Extensible** - Custom suffix generators and vocabulary\n- 📝 **Elixir** - Full type specs and documentation\n- ⚡ **Fast** - High-performance ID generation\n- 🪶 **Lightweight** - Small vocabulary, zero dependencies","ref":"readme.html#features"},{"type":"extras","title":"Installation - MemorableIds","doc":"Add `memorable_ids` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:memorable_ids, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - MemorableIds","doc":"```elixir\n# Basic usage - 2 components\nMemorableIds.generate() # \"cute-rabbit\"\n\n# More components for uniqueness\nMemorableIds.generate(%{components: 3}) # \"large-fox-swim\"\n\n# Add numeric suffix for extra capacity\nsuffix_generators = MemorableIds.suffix_generators()\nMemorableIds.generate(%{\n  components: 2, \n  suffix: suffix_generators.number\n}) # \"quick-mouse-042\"\n\n# Custom separator\nMemorableIds.generate(%{\n  components: 2, \n  separator: \"_\"\n}) # \"warm_duck\"\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"API Reference - MemorableIds","doc":"### `generate(options \\\\ %{})`\n\nGenerate a memorable ID with customizable options.\n\n**Parameters:**\n- `options.components` (integer, 1-5): Number of word components (default: 2)\n- `options.suffix` (function): Suffix generator function (default: nil)\n- `options.separator` (string): Separator between parts (default: \"-\")\n\n**Returns:** `string` - Generated memorable ID\n\n**Examples:**\n\n```elixir\n# Different component counts\nMemorableIds.generate(%{components: 1}) # \"bright\"\nMemorableIds.generate(%{components: 2}) # \"cute-rabbit\" \nMemorableIds.generate(%{components: 3}) # \"large-fox-swim\"\nMemorableIds.generate(%{components: 4}) # \"happy-owl-dance-quietly\"\nMemorableIds.generate(%{components: 5}) # \"clever-fox-run-quickly-through\"\n\n# With suffixes\nsuffix_generators = MemorableIds.suffix_generators()\nMemorableIds.generate(%{\n  components: 2, \n  suffix: suffix_generators.number\n}) # \"safe-rabbit-042\"\n\nMemorableIds.generate(%{\n  components: 2, \n  suffix: suffix_generators.hex\n}) # \"bright-owl-a7\"\n\n# Custom separators\nMemorableIds.generate(%{separator: \"_\"}) # \"warm_duck\"\nMemorableIds.generate(%{separator: \".\"}) # \"cute.rabbit\"\n```\n\n### `parse(id, separator \\\\ \"-\")`\n\nParse a memorable ID back to its components.\n\n**Parameters:**\n- `id` (string): The memorable ID to parse\n- `separator` (string): Separator used (default: \"-\")\n\n**Returns:** `map` - Map with `components` list and `suffix` string\n\n**Examples:**\n\n```elixir\nMemorableIds.parse(\"cute-rabbit-042\")\n# %{components: [\"cute\", \"rabbit\"], suffix: \"042\"}\n\nMemorableIds.parse(\"large-fox-swim\")\n# %{components: [\"large\", \"fox\", \"swim\"], suffix: nil}\n\nMemorableIds.parse(\"warm_duck_123\", \"_\")\n# %{components: [\"warm\", \"duck\"], suffix: \"123\"}\n```","ref":"readme.html#api-reference"},{"type":"extras","title":"Suffix Generators - MemorableIds","doc":"Pre-built suffix generators for common use cases:\n\n```elixir\nsuffix_generators = MemorableIds.suffix_generators()\n\n# 3-digit number (000-999) - adds 1,000x multiplier\nsuffix_generators.number.() # \"042\"\n\n# 4-digit number (0000-9999) - adds 10,000x multiplier  \nsuffix_generators.number4.() # \"1337\"\n\n# 2-digit hex (00-ff) - adds 256x multiplier\nsuffix_generators.hex.() # \"a7\"\n\n# Timestamp (last 4 digits) - time-based\nsuffix_generators.timestamp.() # \"8429\"\n\n# Single letter (a-z) - adds 26x multiplier\nsuffix_generators.letter.() # \"k\"\n```","ref":"readme.html#suffix-generators"},{"type":"extras","title":"Analysis Functions - MemorableIds","doc":"Plan capacity and understand collision probabilities:\n\n```elixir\n# Calculate total possible combinations\nMemorableIds.calculate_combinations(2) # 5,304 (2 components)\nMemorableIds.calculate_combinations(2, 1000) # 5,304,000 (2 components + 3-digit suffix)\nMemorableIds.calculate_combinations(3) # 212,160 (3 components)\n\n# Calculate collision probability (Birthday Paradox)\nMemorableIds.calculate_collision_probability(5304, 100) # 0.0093 (0.93% chance)\n\n# Get comprehensive analysis\nMemorableIds.get_collision_analysis(2)\n# %{\n#   total_combinations: 5304,\n#   scenarios: [\n#     %{ids: 50, probability: 0.0023, percentage: \"0.23%\"},\n#     %{ids: 100, probability: 0.0093, percentage: \"0.93%\"},\n#     %{ids: 200, probability: 0.037, percentage: \"3.7%\"},\n#     %{ids: 500, probability: 0.218, percentage: \"21.8%\"}\n#   ]\n# }\n```","ref":"readme.html#analysis-functions"},{"type":"extras","title":"Capacity & Collision Analysis - MemorableIds","doc":"","ref":"readme.html#capacity-collision-analysis"},{"type":"extras","title":"Total Combinations by Component Count - MemorableIds","doc":"| Components | Total IDs   | Example                          |\n|------------|-------------|----------------------------------|\n| 1          | 78          | `bright`                         |\n| 2          | 5,304       | `cute-rabbit`                    |\n| 3          | 212,160     | `large-fox-swim`                 |\n| 4          | 5,728,320   | `happy-owl-dance-quietly`        |\n| 5          | 148,936,320 | `clever-fox-run-quickly-through` |","ref":"readme.html#total-combinations-by-component-count"},{"type":"extras","title":"Suffix Multipliers - MemorableIds","doc":"| Suffix Type    | Multiplier | Example            |\n|----------------|------------|--------------------|\n| 3-digit number | ×1,000     | `cute-rabbit-042`  |\n| 4-digit number | ×10,000    | `cute-rabbit-1337` |\n| 2-digit hex    | ×256       | `cute-rabbit-a7`   |\n| Single letter  | ×26        | `cute-rabbit-k`    |","ref":"readme.html#suffix-multipliers"},{"type":"extras","title":"Collision Probability Examples - MemorableIds","doc":"**For 2 components (5,304 total combinations):**\n- 50 IDs: 0.23% collision chance\n- 100 IDs: 0.93% collision chance  \n- 200 IDs: 3.7% collision chance\n- 500 IDs: 21.8% collision chance\n\n**For 3 components (212,160 total combinations):**\n- 1,000 IDs: 0.002% collision chance\n- 5,000 IDs: 0.059% collision chance\n- 10,000 IDs: 0.235% collision chance\n- 20,000 IDs: 0.94% collision chance\n\n**For 2 components + 3-digit suffix (5,304,000 total combinations):**\n- 10,000 IDs: 0.0009% collision chance\n- 50,000 IDs: 0.023% collision chance\n- 100,000 IDs: 0.094% collision chance\n- 500,000 IDs: 2.35% collision chance","ref":"readme.html#collision-probability-examples"},{"type":"extras","title":"Configuration Recommendations - MemorableIds","doc":"Choose the right configuration based on your expected ID volume:\n\n| Use Case                  | Recommendation          | Capacity | Example               |\n|---------------------------|-------------------------|----------|-----------------------|\n| Small apps (<1K IDs)      | 2 components            | 5,304    | `cute-rabbit`         |\n| Medium apps (1K-50K IDs)  | 3 components            | 212,160  | `large-fox-swim`      |\n| Large apps (50K-500K IDs) | 2-3 components + suffix | 5M+      | `cute-rabbit-042`     |\n| Enterprise (500K+ IDs)    | 4+ components + suffix  | 50M+     | `happy-owl-dance-042` |","ref":"readme.html#configuration-recommendations"},{"type":"extras","title":"Advanced Usage - MemorableIds","doc":"","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Custom Suffix Generators - MemorableIds","doc":"Create your own suffix logic:\n\n```elixir\n# Custom timestamp suffix\ntimestamp_suffix = fn ->\n  DateTime.utc_now()\n  |> DateTime.to_unix(:millisecond)\n  |> Integer.to_string()\n  |> String.slice(-6..-1) # Last 6 digits\nend\n\n# Custom random string\nrandom_string = fn ->\n  :crypto.strong_rand_bytes(3)\n  |> Base.encode32(case: :lower, padding: false)\n  |> String.slice(0..2) # 3 random chars\nend\n\n# Use custom suffix\nMemorableIds.generate(%{\n  components: 2, \n  suffix: timestamp_suffix\n}) # \"cute-rabbit-123456\"\n```","ref":"readme.html#custom-suffix-generators"},{"type":"extras","title":"Dictionary Access - MemorableIds","doc":"Access the underlying word collections:\n\n```elixir\nalias MemorableIds.Dictionary\n\nIO.puts length(Dictionary.adjectives()) # 78\nIO.puts length(Dictionary.nouns()) # 68\nIO.puts length(Dictionary.verbs()) # 40\nIO.puts length(Dictionary.adverbs()) # 27\nIO.puts length(Dictionary.prepositions()) # 26\n\n# Access individual words\nIO.puts hd(Dictionary.adjectives()) # \"cute\"\nIO.puts hd(Dictionary.nouns()) # \"rabbit\"\n\n# Get statistics\nstats = Dictionary.stats()\nIO.inspect stats\n# %{adjectives: 78, nouns: 68, verbs: 40, adverbs: 27, prepositions: 26}\n```","ref":"readme.html#dictionary-access"},{"type":"extras","title":"Error Handling - MemorableIds","doc":"```elixir\ntry do\n  MemorableIds.generate(%{components: 6}) # Invalid: max is 5\nrescue\n  ArgumentError -> IO.puts \"Components must be between 1 and 5\"\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Performance Considerations - MemorableIds","doc":"","ref":"readme.html#performance-considerations"},{"type":"extras","title":"Generation Speed - MemorableIds","doc":"- **High-performance** ID generation suitable for production use\n- No significant performance difference between component counts\n- Suffix generation adds minimal overhead","ref":"readme.html#generation-speed"},{"type":"extras","title":"Randomness Quality - MemorableIds","doc":"- Uses Erlang's `:rand` module - suitable for non-cryptographic purposes\n- For cryptographic security, replace with `:crypto.strong_rand_bytes/1`\n- Distribution is uniform across all vocabulary combinations","ref":"readme.html#randomness-quality"},{"type":"extras","title":"Security Notes - MemorableIds","doc":"⚠️ **Important Security Information:**\n\n- IDs are **NOT cryptographically secure**\n- Predictable if random seed is known\n- **Suitable for**: user-friendly identifiers, temporary IDs, non-sensitive references\n- **NOT suitable for**: session tokens, passwords, security-critical identifiers","ref":"readme.html#security-notes"},{"type":"extras","title":"Development - MemorableIds","doc":"","ref":"readme.html#development"},{"type":"extras","title":"Running Tests - MemorableIds","doc":"```bash\n# Run all tests\nmix test\n\n# Run with coverage\nmix test --cover\n\n# Run specific test file\nmix test test/memorable_ids_test.exs\n\n# Run doctests only\nmix test --only doctest\n```","ref":"readme.html#running-tests"},{"type":"extras","title":"Building Documentation - MemorableIds","doc":"```bash\n# Generate documentation\nmix docs\n\n# View documentation\nopen doc/index.html\n```","ref":"readme.html#building-documentation"},{"type":"extras","title":"Contributing - MemorableIds","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"Development Setup - MemorableIds","doc":"```bash\n# Clone repository\ngit clone  \ncd memorable_ids\n\n# Install dependencies\nmix deps.get\n\n# Run tests\nmix test\n\n# Check formatting\nmix format --check-formatted\n\n# Run static analysis\nmix credo\n```","ref":"readme.html#development-setup"},{"type":"extras","title":"Adding Custom Vocabulary - MemorableIds","doc":"1. Extend existing lists in `lib/dictionary.ex`\n2. Ensure words are URL-safe and human-readable\n3. Avoid duplicates to maintain combination count accuracy\n4. Update tests and documentation\n5. Run `mix test` to verify changes","ref":"readme.html#adding-custom-vocabulary"},{"type":"extras","title":"Documentation - MemorableIds","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm).\n\nOnce published, the docs can be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - MemorableIds","doc":"This project is open-sourced software licensed under the [MIT license](https://choosealicense.com/licenses/mit/).\n\nCopyrights in this project are retained by their contributors.\nSee the [license file](./LICENSE) for more information.\n\n---\n\n 🤫 Psst! If you like my work you can support me via [GitHub sponsors](https://github.com/sponsors/riipandi).","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}